1.2.1 (September 22, 2020)
==========================
This micro version fixes a few small things in the documentation.

  * Doc fixes (#15)


1.2 (September 22, 2020)
========================
This version substantially overhauls the documentation and adds a
cross-validation estimator.

  * Documentation overhaul. (#12)
  * FracRidgeCV estimator (#13)


Version 1.1 (June 29, 2020)
===================

This version adds more documentation

Version 1.0 (May 07, 2020)
==========================

This is the first major release of the software, in tandem with the appearance
of the preprint about the method.


